@use "node_modules/@picocss/pico/scss" with (
  $theme-color: "green"
);

//some root overrides for scale https://github.com/picocss/pico/discussions/482

:root {
  --pico-font-family-sans-serif: Inter, system-ui, "Segoe UI", Roboto, Oxygen, Ubuntu, Cantarell, Helvetica, Arial, "Helvetica Neue", sans-serif, var(--pico-font-family-emoji);
  --pico-font-size: 106.25%;                        /* Original: 100% */
  --pico-line-height: 1.25;                         /* Original: 1.5 */
  --pico-form-element-spacing-vertical: 0.5rem;     /* Original: 1rem */
  --pico-form-element-spacing-horizontal: 1.0rem;   /* Original: 1.25rem */
  --pico-border-radius: 0.375rem;                   /* Original: 0.25rem */
}

h1,
h2,
h3,
h4,
h5,
h6 {
  --pico-font-weight: 600;                          /* Original: 700 */
}

article {
  border: 1px solid var(--pico-muted-border-color); /* Original doesn't have a border */
  border-radius: calc(var(--pico-border-radius) * 2); /* Original: var(--pico-border-radius) */
}

article>footer {
  border-radius: calc(var(--pico-border-radius) * 2); /* Original: var(--pico-border-radius) */
}

b {
  color: red;
}

.logo, .logo:hover {
  /* Remove underline by default and on hover */
  text-decoration: none;
  font-size:160%;
  font-weight:700;
}

body > footer > p {
  font-size:66%;
  font-style:italic;
}


