@use "sass:map";
@use "../settings" as *;

@if map.get($modules, "utilities/accessibility") {
  /**
   * Accessibility & User interaction
   */

  // Based on :
  // - normalize.css v8.0.1 | MIT License | github.com/necolas/normalize.css
  // - sanitize.css v13.0.0 | CC0 1.0 Universal | github.com/csstools/sanitize.css
  // ––––––––––––––––––––

  // Accessibility

  // Change the cursor on control elements in all browsers (opinionated)
  #{$parent-selector} [aria-controls] {
    cursor: pointer;
  }

  // Change the cursor on disabled, not-editable, or otherwise inoperable elements in all browsers (opinionated)
  #{$parent-selector} [aria-disabled="true"],
  #{$parent-selector} [disabled] {
    cursor: not-allowed;
  }

  // Change the display on visually hidden routable elements in all browsers (opinionated)
  #{$parent-selector} [aria-hidden="false"][hidden] {
    display: initial;
  }

  #{$parent-selector} [aria-hidden="false"][hidden]:not(:focus) {
    clip: rect(0, 0, 0, 0);
    position: absolute;
  }

  // User interaction
  // Remove the tapping delay in IE 10
  #{$parent-selector} a,
  #{$parent-selector} area,
  #{$parent-selector} button,
  #{$parent-selector} input,
  #{$parent-selector} label,
  #{$parent-selector} select,
  #{$parent-selector} summary,
  #{$parent-selector} textarea,
  #{$parent-selector} [tabindex] {
    -ms-touch-action: manipulation;
  }

  // Pico
  // ––––––––––––––––––––

  #{$parent-selector} [dir="rtl"] {
    direction: rtl;
  }
}
