@charset "UTF-8";
/*!
 * Pico CSS ✨ v2.0.6 (https://picocss.com)
 * Copyright 2019-2024 - Licensed under MIT
 */
:root {
  --pico-color-red-950: #1c0d06;
  --pico-color-red-900: #30130a;
  --pico-color-red-850: #45150c;
  --pico-color-red-800: #5c160d;
  --pico-color-red-750: #72170f;
  --pico-color-red-700: #861d13;
  --pico-color-red-650: #9b2318;
  --pico-color-red-600: #af291d;
  --pico-color-red-550: #c52f21;
  --pico-color-red-500: #d93526;
  --pico-color-red-450: #ee402e;
  --pico-color-red-400: #f06048;
  --pico-color-red-350: #f17961;
  --pico-color-red-300: #f38f79;
  --pico-color-red-250: #f5a390;
  --pico-color-red-200: #f5b7a8;
  --pico-color-red-150: #f6cabf;
  --pico-color-red-100: #f8dcd6;
  --pico-color-red-50: #faeeeb;
  --pico-color-red: #c52f21;
  --pico-color-pink-950: #25060c;
  --pico-color-pink-900: #380916;
  --pico-color-pink-850: #4b0c1f;
  --pico-color-pink-800: #5f0e28;
  --pico-color-pink-750: #740f31;
  --pico-color-pink-700: #88143b;
  --pico-color-pink-650: #9d1945;
  --pico-color-pink-600: #b21e4f;
  --pico-color-pink-550: #c72259;
  --pico-color-pink-500: #d92662;
  --pico-color-pink-450: #f42c6f;
  --pico-color-pink-400: #f6547e;
  --pico-color-pink-350: #f7708e;
  --pico-color-pink-300: #f8889e;
  --pico-color-pink-250: #f99eae;
  --pico-color-pink-200: #f9b4be;
  --pico-color-pink-150: #f9c8ce;
  --pico-color-pink-100: #f9dbdf;
  --pico-color-pink-50: #fbedef;
  --pico-color-pink: #d92662;
  --pico-color-fuchsia-950: #230518;
  --pico-color-fuchsia-900: #360925;
  --pico-color-fuchsia-850: #480b33;
  --pico-color-fuchsia-800: #5c0d41;
  --pico-color-fuchsia-750: #700e4f;
  --pico-color-fuchsia-700: #84135e;
  --pico-color-fuchsia-650: #98176d;
  --pico-color-fuchsia-600: #ac1c7c;
  --pico-color-fuchsia-550: #c1208b;
  --pico-color-fuchsia-500: #d9269d;
  --pico-color-fuchsia-450: #ed2aac;
  --pico-color-fuchsia-400: #f748b7;
  --pico-color-fuchsia-350: #f869bf;
  --pico-color-fuchsia-300: #f983c7;
  --pico-color-fuchsia-250: #fa9acf;
  --pico-color-fuchsia-200: #f9b1d8;
  --pico-color-fuchsia-150: #f9c6e1;
  --pico-color-fuchsia-100: #f9daea;
  --pico-color-fuchsia-50: #fbedf4;
  --pico-color-fuchsia: #c1208b;
  --pico-color-purple-950: #1e0820;
  --pico-color-purple-900: #2d0f33;
  --pico-color-purple-850: #3d1545;
  --pico-color-purple-800: #4d1a57;
  --pico-color-purple-750: #5e206b;
  --pico-color-purple-700: #6f277d;
  --pico-color-purple-650: #802e90;
  --pico-color-purple-600: #9236a4;
  --pico-color-purple-550: #aa40bf;
  --pico-color-purple-500: #b645cd;
  --pico-color-purple-450: #c652dc;
  --pico-color-purple-400: #cd68e0;
  --pico-color-purple-350: #d47de4;
  --pico-color-purple-300: #db90e8;
  --pico-color-purple-250: #e2a3eb;
  --pico-color-purple-200: #e7b6ee;
  --pico-color-purple-150: #edc9f1;
  --pico-color-purple-100: #f2dcf4;
  --pico-color-purple-50: #f8eef9;
  --pico-color-purple: #9236a4;
  --pico-color-violet-950: #190928;
  --pico-color-violet-900: #251140;
  --pico-color-violet-850: #321856;
  --pico-color-violet-800: #3f1e6d;
  --pico-color-violet-750: #4d2585;
  --pico-color-violet-700: #5b2d9c;
  --pico-color-violet-650: #6935b3;
  --pico-color-violet-600: #7540bf;
  --pico-color-violet-550: #8352c5;
  --pico-color-violet-500: #9062ca;
  --pico-color-violet-450: #9b71cf;
  --pico-color-violet-400: #a780d4;
  --pico-color-violet-350: #b290d9;
  --pico-color-violet-300: #bd9fdf;
  --pico-color-violet-250: #c9afe4;
  --pico-color-violet-200: #d3bfe8;
  --pico-color-violet-150: #decfed;
  --pico-color-violet-100: #e8dff2;
  --pico-color-violet-50: #f3eff7;
  --pico-color-violet: #7540bf;
  --pico-color-indigo-950: #110b31;
  --pico-color-indigo-900: #181546;
  --pico-color-indigo-850: #1f1e5e;
  --pico-color-indigo-800: #272678;
  --pico-color-indigo-750: #2f2f92;
  --pico-color-indigo-700: #3838ab;
  --pico-color-indigo-650: #4040bf;
  --pico-color-indigo-600: #524ed2;
  --pico-color-indigo-550: #655cd6;
  --pico-color-indigo-500: #7569da;
  --pico-color-indigo-450: #8577dd;
  --pico-color-indigo-400: #9486e1;
  --pico-color-indigo-350: #a294e5;
  --pico-color-indigo-300: #b0a3e8;
  --pico-color-indigo-250: #bdb2ec;
  --pico-color-indigo-200: #cac1ee;
  --pico-color-indigo-150: #d8d0f1;
  --pico-color-indigo-100: #e5e0f4;
  --pico-color-indigo-50: #f2f0f9;
  --pico-color-indigo: #524ed2;
  --pico-color-blue-950: #080f2d;
  --pico-color-blue-900: #0c1a41;
  --pico-color-blue-850: #0e2358;
  --pico-color-blue-800: #0f2d70;
  --pico-color-blue-750: #0f3888;
  --pico-color-blue-700: #1343a0;
  --pico-color-blue-650: #184eb8;
  --pico-color-blue-600: #1d59d0;
  --pico-color-blue-550: #2060df;
  --pico-color-blue-500: #3c71f7;
  --pico-color-blue-450: #5c7ef8;
  --pico-color-blue-400: #748bf8;
  --pico-color-blue-350: #8999f9;
  --pico-color-blue-300: #9ca7fa;
  --pico-color-blue-250: #aeb5fb;
  --pico-color-blue-200: #bfc3fa;
  --pico-color-blue-150: #d0d2fa;
  --pico-color-blue-100: #e0e1fa;
  --pico-color-blue-50: #f0f0fb;
  --pico-color-blue: #2060df;
  --pico-color-azure-950: #04121d;
  --pico-color-azure-900: #061e2f;
  --pico-color-azure-850: #052940;
  --pico-color-azure-800: #033452;
  --pico-color-azure-750: #014063;
  --pico-color-azure-700: #014c75;
  --pico-color-azure-650: #015887;
  --pico-color-azure-600: #02659a;
  --pico-color-azure-550: #0172ad;
  --pico-color-azure-500: #017fc0;
  --pico-color-azure-450: #018cd4;
  --pico-color-azure-400: #029ae8;
  --pico-color-azure-350: #01aaff;
  --pico-color-azure-300: #51b4ff;
  --pico-color-azure-250: #79c0ff;
  --pico-color-azure-200: #9bccfd;
  --pico-color-azure-150: #b7d9fc;
  --pico-color-azure-100: #d1e5fb;
  --pico-color-azure-50: #e9f2fc;
  --pico-color-azure: #0172ad;
  --pico-color-cyan-950: #041413;
  --pico-color-cyan-900: #051f1f;
  --pico-color-cyan-850: #052b2b;
  --pico-color-cyan-800: #043737;
  --pico-color-cyan-750: #014343;
  --pico-color-cyan-700: #015050;
  --pico-color-cyan-650: #025d5d;
  --pico-color-cyan-600: #046a6a;
  --pico-color-cyan-550: #047878;
  --pico-color-cyan-500: #058686;
  --pico-color-cyan-450: #059494;
  --pico-color-cyan-400: #05a2a2;
  --pico-color-cyan-350: #0ab1b1;
  --pico-color-cyan-300: #0ac2c2;
  --pico-color-cyan-250: #0ccece;
  --pico-color-cyan-200: #25dddd;
  --pico-color-cyan-150: #3deceb;
  --pico-color-cyan-100: #58faf9;
  --pico-color-cyan-50: #c3fcfa;
  --pico-color-cyan: #047878;
  --pico-color-jade-950: #04140c;
  --pico-color-jade-900: #052014;
  --pico-color-jade-850: #042c1b;
  --pico-color-jade-800: #033823;
  --pico-color-jade-750: #00452b;
  --pico-color-jade-700: #015234;
  --pico-color-jade-650: #005f3d;
  --pico-color-jade-600: #006d46;
  --pico-color-jade-550: #007a50;
  --pico-color-jade-500: #00895a;
  --pico-color-jade-450: #029764;
  --pico-color-jade-400: #00a66e;
  --pico-color-jade-350: #00b478;
  --pico-color-jade-300: #00c482;
  --pico-color-jade-250: #00cc88;
  --pico-color-jade-200: #21e299;
  --pico-color-jade-150: #39f1a6;
  --pico-color-jade-100: #70fcba;
  --pico-color-jade-50: #cbfce1;
  --pico-color-jade: #007a50;
  --pico-color-green-950: #0b1305;
  --pico-color-green-900: #131f07;
  --pico-color-green-850: #152b07;
  --pico-color-green-800: #173806;
  --pico-color-green-750: #1a4405;
  --pico-color-green-700: #205107;
  --pico-color-green-650: #265e09;
  --pico-color-green-600: #2c6c0c;
  --pico-color-green-550: #33790f;
  --pico-color-green-500: #398712;
  --pico-color-green-450: #409614;
  --pico-color-green-400: #47a417;
  --pico-color-green-350: #4eb31b;
  --pico-color-green-300: #55c21e;
  --pico-color-green-250: #5dd121;
  --pico-color-green-200: #62d926;
  --pico-color-green-150: #77ef3d;
  --pico-color-green-100: #95fb62;
  --pico-color-green-50: #d7fbc1;
  --pico-color-green: #398712;
  --pico-color-lime-950: #101203;
  --pico-color-lime-900: #191d03;
  --pico-color-lime-850: #202902;
  --pico-color-lime-800: #273500;
  --pico-color-lime-750: #304100;
  --pico-color-lime-700: #394d00;
  --pico-color-lime-650: #435a00;
  --pico-color-lime-600: #4d6600;
  --pico-color-lime-550: #577400;
  --pico-color-lime-500: #628100;
  --pico-color-lime-450: #6c8f00;
  --pico-color-lime-400: #779c00;
  --pico-color-lime-350: #82ab00;
  --pico-color-lime-300: #8eb901;
  --pico-color-lime-250: #99c801;
  --pico-color-lime-200: #a5d601;
  --pico-color-lime-150: #b2e51a;
  --pico-color-lime-100: #c1f335;
  --pico-color-lime-50: #defc85;
  --pico-color-lime: #a5d601;
  --pico-color-yellow-950: #141103;
  --pico-color-yellow-900: #1f1c02;
  --pico-color-yellow-850: #2b2600;
  --pico-color-yellow-800: #363100;
  --pico-color-yellow-750: #423c00;
  --pico-color-yellow-700: #4e4700;
  --pico-color-yellow-650: #5b5300;
  --pico-color-yellow-600: #685f00;
  --pico-color-yellow-550: #756b00;
  --pico-color-yellow-500: #827800;
  --pico-color-yellow-450: #908501;
  --pico-color-yellow-400: #9e9200;
  --pico-color-yellow-350: #ad9f00;
  --pico-color-yellow-300: #bbac00;
  --pico-color-yellow-250: #caba01;
  --pico-color-yellow-200: #d9c800;
  --pico-color-yellow-150: #e8d600;
  --pico-color-yellow-100: #f2df0d;
  --pico-color-yellow-50: #fdf1b4;
  --pico-color-yellow: #f2df0d;
  --pico-color-amber-950: #161003;
  --pico-color-amber-900: #231a03;
  --pico-color-amber-850: #312302;
  --pico-color-amber-800: #3f2d00;
  --pico-color-amber-750: #4d3700;
  --pico-color-amber-700: #5b4200;
  --pico-color-amber-650: #694d00;
  --pico-color-amber-600: #785800;
  --pico-color-amber-550: #876400;
  --pico-color-amber-500: #977000;
  --pico-color-amber-450: #a77c00;
  --pico-color-amber-400: #b78800;
  --pico-color-amber-350: #c79400;
  --pico-color-amber-300: #d8a100;
  --pico-color-amber-250: #e8ae01;
  --pico-color-amber-200: #ffbf00;
  --pico-color-amber-150: #fecc63;
  --pico-color-amber-100: #fddea6;
  --pico-color-amber-50: #fcefd9;
  --pico-color-amber: #ffbf00;
  --pico-color-pumpkin-950: #180f04;
  --pico-color-pumpkin-900: #271805;
  --pico-color-pumpkin-850: #372004;
  --pico-color-pumpkin-800: #482802;
  --pico-color-pumpkin-750: #593100;
  --pico-color-pumpkin-700: #693a00;
  --pico-color-pumpkin-650: #7a4400;
  --pico-color-pumpkin-600: #8b4f00;
  --pico-color-pumpkin-550: #9c5900;
  --pico-color-pumpkin-500: #ad6400;
  --pico-color-pumpkin-450: #bf6e00;
  --pico-color-pumpkin-400: #d27a01;
  --pico-color-pumpkin-350: #e48500;
  --pico-color-pumpkin-300: #ff9500;
  --pico-color-pumpkin-250: #ffa23a;
  --pico-color-pumpkin-200: #feb670;
  --pico-color-pumpkin-150: #fcca9b;
  --pico-color-pumpkin-100: #fcdcc1;
  --pico-color-pumpkin-50: #fceee3;
  --pico-color-pumpkin: #ff9500;
  --pico-color-orange-950: #1b0d06;
  --pico-color-orange-900: #2d1509;
  --pico-color-orange-850: #411a0a;
  --pico-color-orange-800: #561e0a;
  --pico-color-orange-750: #6b220a;
  --pico-color-orange-700: #7f270b;
  --pico-color-orange-650: #942d0d;
  --pico-color-orange-600: #a83410;
  --pico-color-orange-550: #bd3c13;
  --pico-color-orange-500: #d24317;
  --pico-color-orange-450: #e74b1a;
  --pico-color-orange-400: #f45d2c;
  --pico-color-orange-350: #f56b3d;
  --pico-color-orange-300: #f68e68;
  --pico-color-orange-250: #f8a283;
  --pico-color-orange-200: #f8b79f;
  --pico-color-orange-150: #f8cab9;
  --pico-color-orange-100: #f9dcd2;
  --pico-color-orange-50: #faeeea;
  --pico-color-orange: #d24317;
  --pico-color-sand-950: #111110;
  --pico-color-sand-900: #1c1b19;
  --pico-color-sand-850: #272622;
  --pico-color-sand-800: #32302b;
  --pico-color-sand-750: #3d3b35;
  --pico-color-sand-700: #49463f;
  --pico-color-sand-650: #55524a;
  --pico-color-sand-600: #615e55;
  --pico-color-sand-550: #6e6a60;
  --pico-color-sand-500: #7b776b;
  --pico-color-sand-450: #888377;
  --pico-color-sand-400: #959082;
  --pico-color-sand-350: #a39e8f;
  --pico-color-sand-300: #b0ab9b;
  --pico-color-sand-250: #beb8a7;
  --pico-color-sand-200: #ccc6b4;
  --pico-color-sand-150: #dad4c2;
  --pico-color-sand-100: #e8e2d2;
  --pico-color-sand-50: #f2f0ec;
  --pico-color-sand: #ccc6b4;
  --pico-color-grey-950: #111111;
  --pico-color-grey-900: #1b1b1b;
  --pico-color-grey-850: #262626;
  --pico-color-grey-800: #303030;
  --pico-color-grey-750: #3b3b3b;
  --pico-color-grey-700: #474747;
  --pico-color-grey-650: #525252;
  --pico-color-grey-600: #5e5e5e;
  --pico-color-grey-550: #6a6a6a;
  --pico-color-grey-500: #777777;
  --pico-color-grey-450: #808080;
  --pico-color-grey-400: #919191;
  --pico-color-grey-350: #9e9e9e;
  --pico-color-grey-300: #ababab;
  --pico-color-grey-250: #b9b9b9;
  --pico-color-grey-200: #c6c6c6;
  --pico-color-grey-150: #d4d4d4;
  --pico-color-grey-100: #e2e2e2;
  --pico-color-grey-50: #f1f1f1;
  --pico-color-grey: #ababab;
  --pico-color-zinc-950: #0f1114;
  --pico-color-zinc-900: #191c20;
  --pico-color-zinc-850: #23262c;
  --pico-color-zinc-800: #2d3138;
  --pico-color-zinc-750: #373c44;
  --pico-color-zinc-700: #424751;
  --pico-color-zinc-650: #4d535e;
  --pico-color-zinc-600: #5c6370;
  --pico-color-zinc-550: #646b79;
  --pico-color-zinc-500: #6f7887;
  --pico-color-zinc-450: #7b8495;
  --pico-color-zinc-400: #8891a4;
  --pico-color-zinc-350: #969eaf;
  --pico-color-zinc-300: #a4acba;
  --pico-color-zinc-250: #b3b9c5;
  --pico-color-zinc-200: #c2c7d0;
  --pico-color-zinc-150: #d1d5db;
  --pico-color-zinc-100: #e0e3e7;
  --pico-color-zinc-50: #f0f1f3;
  --pico-color-zinc: #646b79;
  --pico-color-slate-950: #0e1118;
  --pico-color-slate-900: #181c25;
  --pico-color-slate-850: #202632;
  --pico-color-slate-800: #2a3140;
  --pico-color-slate-750: #333c4e;
  --pico-color-slate-700: #3d475c;
  --pico-color-slate-650: #48536b;
  --pico-color-slate-600: #525f7a;
  --pico-color-slate-550: #5d6b89;
  --pico-color-slate-500: #687899;
  --pico-color-slate-450: #7385a9;
  --pico-color-slate-400: #8191b5;
  --pico-color-slate-350: #909ebe;
  --pico-color-slate-300: #a0acc7;
  --pico-color-slate-250: #b0b9d0;
  --pico-color-slate-200: #bfc7d9;
  --pico-color-slate-150: #cfd5e2;
  --pico-color-slate-100: #dfe3eb;
  --pico-color-slate-50: #eff1f4;
  --pico-color-slate: #525f7a;
  --pico-color-light: #fff;
  --pico-color-dark: #000;
}

.pico-color-red-950 {
  color: var(--pico-color-red-950);
}

.pico-color-red-900 {
  color: var(--pico-color-red-900);
}

.pico-color-red-850 {
  color: var(--pico-color-red-850);
}

.pico-color-red-800 {
  color: var(--pico-color-red-800);
}

.pico-color-red-750 {
  color: var(--pico-color-red-750);
}

.pico-color-red-700 {
  color: var(--pico-color-red-700);
}

.pico-color-red-650 {
  color: var(--pico-color-red-650);
}

.pico-color-red-600 {
  color: var(--pico-color-red-600);
}

.pico-color-red-550 {
  color: var(--pico-color-red-550);
}

.pico-color-red-500 {
  color: var(--pico-color-red-500);
}

.pico-color-red-450 {
  color: var(--pico-color-red-450);
}

.pico-color-red-400 {
  color: var(--pico-color-red-400);
}

.pico-color-red-350 {
  color: var(--pico-color-red-350);
}

.pico-color-red-300 {
  color: var(--pico-color-red-300);
}

.pico-color-red-250 {
  color: var(--pico-color-red-250);
}

.pico-color-red-200 {
  color: var(--pico-color-red-200);
}

.pico-color-red-150 {
  color: var(--pico-color-red-150);
}

.pico-color-red-100 {
  color: var(--pico-color-red-100);
}

.pico-color-red-50 {
  color: var(--pico-color-red-50);
}

.pico-color-red {
  color: var(--pico-color-red);
}

.pico-color-pink-950 {
  color: var(--pico-color-pink-950);
}

.pico-color-pink-900 {
  color: var(--pico-color-pink-900);
}

.pico-color-pink-850 {
  color: var(--pico-color-pink-850);
}

.pico-color-pink-800 {
  color: var(--pico-color-pink-800);
}

.pico-color-pink-750 {
  color: var(--pico-color-pink-750);
}

.pico-color-pink-700 {
  color: var(--pico-color-pink-700);
}

.pico-color-pink-650 {
  color: var(--pico-color-pink-650);
}

.pico-color-pink-600 {
  color: var(--pico-color-pink-600);
}

.pico-color-pink-550 {
  color: var(--pico-color-pink-550);
}

.pico-color-pink-500 {
  color: var(--pico-color-pink-500);
}

.pico-color-pink-450 {
  color: var(--pico-color-pink-450);
}

.pico-color-pink-400 {
  color: var(--pico-color-pink-400);
}

.pico-color-pink-350 {
  color: var(--pico-color-pink-350);
}

.pico-color-pink-300 {
  color: var(--pico-color-pink-300);
}

.pico-color-pink-250 {
  color: var(--pico-color-pink-250);
}

.pico-color-pink-200 {
  color: var(--pico-color-pink-200);
}

.pico-color-pink-150 {
  color: var(--pico-color-pink-150);
}

.pico-color-pink-100 {
  color: var(--pico-color-pink-100);
}

.pico-color-pink-50 {
  color: var(--pico-color-pink-50);
}

.pico-color-pink {
  color: var(--pico-color-pink);
}

.pico-color-fuchsia-950 {
  color: var(--pico-color-fuchsia-950);
}

.pico-color-fuchsia-900 {
  color: var(--pico-color-fuchsia-900);
}

.pico-color-fuchsia-850 {
  color: var(--pico-color-fuchsia-850);
}

.pico-color-fuchsia-800 {
  color: var(--pico-color-fuchsia-800);
}

.pico-color-fuchsia-750 {
  color: var(--pico-color-fuchsia-750);
}

.pico-color-fuchsia-700 {
  color: var(--pico-color-fuchsia-700);
}

.pico-color-fuchsia-650 {
  color: var(--pico-color-fuchsia-650);
}

.pico-color-fuchsia-600 {
  color: var(--pico-color-fuchsia-600);
}

.pico-color-fuchsia-550 {
  color: var(--pico-color-fuchsia-550);
}

.pico-color-fuchsia-500 {
  color: var(--pico-color-fuchsia-500);
}

.pico-color-fuchsia-450 {
  color: var(--pico-color-fuchsia-450);
}

.pico-color-fuchsia-400 {
  color: var(--pico-color-fuchsia-400);
}

.pico-color-fuchsia-350 {
  color: var(--pico-color-fuchsia-350);
}

.pico-color-fuchsia-300 {
  color: var(--pico-color-fuchsia-300);
}

.pico-color-fuchsia-250 {
  color: var(--pico-color-fuchsia-250);
}

.pico-color-fuchsia-200 {
  color: var(--pico-color-fuchsia-200);
}

.pico-color-fuchsia-150 {
  color: var(--pico-color-fuchsia-150);
}

.pico-color-fuchsia-100 {
  color: var(--pico-color-fuchsia-100);
}

.pico-color-fuchsia-50 {
  color: var(--pico-color-fuchsia-50);
}

.pico-color-fuchsia {
  color: var(--pico-color-fuchsia);
}

.pico-color-purple-950 {
  color: var(--pico-color-purple-950);
}

.pico-color-purple-900 {
  color: var(--pico-color-purple-900);
}

.pico-color-purple-850 {
  color: var(--pico-color-purple-850);
}

.pico-color-purple-800 {
  color: var(--pico-color-purple-800);
}

.pico-color-purple-750 {
  color: var(--pico-color-purple-750);
}

.pico-color-purple-700 {
  color: var(--pico-color-purple-700);
}

.pico-color-purple-650 {
  color: var(--pico-color-purple-650);
}

.pico-color-purple-600 {
  color: var(--pico-color-purple-600);
}

.pico-color-purple-550 {
  color: var(--pico-color-purple-550);
}

.pico-color-purple-500 {
  color: var(--pico-color-purple-500);
}

.pico-color-purple-450 {
  color: var(--pico-color-purple-450);
}

.pico-color-purple-400 {
  color: var(--pico-color-purple-400);
}

.pico-color-purple-350 {
  color: var(--pico-color-purple-350);
}

.pico-color-purple-300 {
  color: var(--pico-color-purple-300);
}

.pico-color-purple-250 {
  color: var(--pico-color-purple-250);
}

.pico-color-purple-200 {
  color: var(--pico-color-purple-200);
}

.pico-color-purple-150 {
  color: var(--pico-color-purple-150);
}

.pico-color-purple-100 {
  color: var(--pico-color-purple-100);
}

.pico-color-purple-50 {
  color: var(--pico-color-purple-50);
}

.pico-color-purple {
  color: var(--pico-color-purple);
}

.pico-color-violet-950 {
  color: var(--pico-color-violet-950);
}

.pico-color-violet-900 {
  color: var(--pico-color-violet-900);
}

.pico-color-violet-850 {
  color: var(--pico-color-violet-850);
}

.pico-color-violet-800 {
  color: var(--pico-color-violet-800);
}

.pico-color-violet-750 {
  color: var(--pico-color-violet-750);
}

.pico-color-violet-700 {
  color: var(--pico-color-violet-700);
}

.pico-color-violet-650 {
  color: var(--pico-color-violet-650);
}

.pico-color-violet-600 {
  color: var(--pico-color-violet-600);
}

.pico-color-violet-550 {
  color: var(--pico-color-violet-550);
}

.pico-color-violet-500 {
  color: var(--pico-color-violet-500);
}

.pico-color-violet-450 {
  color: var(--pico-color-violet-450);
}

.pico-color-violet-400 {
  color: var(--pico-color-violet-400);
}

.pico-color-violet-350 {
  color: var(--pico-color-violet-350);
}

.pico-color-violet-300 {
  color: var(--pico-color-violet-300);
}

.pico-color-violet-250 {
  color: var(--pico-color-violet-250);
}

.pico-color-violet-200 {
  color: var(--pico-color-violet-200);
}

.pico-color-violet-150 {
  color: var(--pico-color-violet-150);
}

.pico-color-violet-100 {
  color: var(--pico-color-violet-100);
}

.pico-color-violet-50 {
  color: var(--pico-color-violet-50);
}

.pico-color-violet {
  color: var(--pico-color-violet);
}

.pico-color-indigo-950 {
  color: var(--pico-color-indigo-950);
}

.pico-color-indigo-900 {
  color: var(--pico-color-indigo-900);
}

.pico-color-indigo-850 {
  color: var(--pico-color-indigo-850);
}

.pico-color-indigo-800 {
  color: var(--pico-color-indigo-800);
}

.pico-color-indigo-750 {
  color: var(--pico-color-indigo-750);
}

.pico-color-indigo-700 {
  color: var(--pico-color-indigo-700);
}

.pico-color-indigo-650 {
  color: var(--pico-color-indigo-650);
}

.pico-color-indigo-600 {
  color: var(--pico-color-indigo-600);
}

.pico-color-indigo-550 {
  color: var(--pico-color-indigo-550);
}

.pico-color-indigo-500 {
  color: var(--pico-color-indigo-500);
}

.pico-color-indigo-450 {
  color: var(--pico-color-indigo-450);
}

.pico-color-indigo-400 {
  color: var(--pico-color-indigo-400);
}

.pico-color-indigo-350 {
  color: var(--pico-color-indigo-350);
}

.pico-color-indigo-300 {
  color: var(--pico-color-indigo-300);
}

.pico-color-indigo-250 {
  color: var(--pico-color-indigo-250);
}

.pico-color-indigo-200 {
  color: var(--pico-color-indigo-200);
}

.pico-color-indigo-150 {
  color: var(--pico-color-indigo-150);
}

.pico-color-indigo-100 {
  color: var(--pico-color-indigo-100);
}

.pico-color-indigo-50 {
  color: var(--pico-color-indigo-50);
}

.pico-color-indigo {
  color: var(--pico-color-indigo);
}

.pico-color-blue-950 {
  color: var(--pico-color-blue-950);
}

.pico-color-blue-900 {
  color: var(--pico-color-blue-900);
}

.pico-color-blue-850 {
  color: var(--pico-color-blue-850);
}

.pico-color-blue-800 {
  color: var(--pico-color-blue-800);
}

.pico-color-blue-750 {
  color: var(--pico-color-blue-750);
}

.pico-color-blue-700 {
  color: var(--pico-color-blue-700);
}

.pico-color-blue-650 {
  color: var(--pico-color-blue-650);
}

.pico-color-blue-600 {
  color: var(--pico-color-blue-600);
}

.pico-color-blue-550 {
  color: var(--pico-color-blue-550);
}

.pico-color-blue-500 {
  color: var(--pico-color-blue-500);
}

.pico-color-blue-450 {
  color: var(--pico-color-blue-450);
}

.pico-color-blue-400 {
  color: var(--pico-color-blue-400);
}

.pico-color-blue-350 {
  color: var(--pico-color-blue-350);
}

.pico-color-blue-300 {
  color: var(--pico-color-blue-300);
}

.pico-color-blue-250 {
  color: var(--pico-color-blue-250);
}

.pico-color-blue-200 {
  color: var(--pico-color-blue-200);
}

.pico-color-blue-150 {
  color: var(--pico-color-blue-150);
}

.pico-color-blue-100 {
  color: var(--pico-color-blue-100);
}

.pico-color-blue-50 {
  color: var(--pico-color-blue-50);
}

.pico-color-blue {
  color: var(--pico-color-blue);
}

.pico-color-azure-950 {
  color: var(--pico-color-azure-950);
}

.pico-color-azure-900 {
  color: var(--pico-color-azure-900);
}

.pico-color-azure-850 {
  color: var(--pico-color-azure-850);
}

.pico-color-azure-800 {
  color: var(--pico-color-azure-800);
}

.pico-color-azure-750 {
  color: var(--pico-color-azure-750);
}

.pico-color-azure-700 {
  color: var(--pico-color-azure-700);
}

.pico-color-azure-650 {
  color: var(--pico-color-azure-650);
}

.pico-color-azure-600 {
  color: var(--pico-color-azure-600);
}

.pico-color-azure-550 {
  color: var(--pico-color-azure-550);
}

.pico-color-azure-500 {
  color: var(--pico-color-azure-500);
}

.pico-color-azure-450 {
  color: var(--pico-color-azure-450);
}

.pico-color-azure-400 {
  color: var(--pico-color-azure-400);
}

.pico-color-azure-350 {
  color: var(--pico-color-azure-350);
}

.pico-color-azure-300 {
  color: var(--pico-color-azure-300);
}

.pico-color-azure-250 {
  color: var(--pico-color-azure-250);
}

.pico-color-azure-200 {
  color: var(--pico-color-azure-200);
}

.pico-color-azure-150 {
  color: var(--pico-color-azure-150);
}

.pico-color-azure-100 {
  color: var(--pico-color-azure-100);
}

.pico-color-azure-50 {
  color: var(--pico-color-azure-50);
}

.pico-color-azure {
  color: var(--pico-color-azure);
}

.pico-color-cyan-950 {
  color: var(--pico-color-cyan-950);
}

.pico-color-cyan-900 {
  color: var(--pico-color-cyan-900);
}

.pico-color-cyan-850 {
  color: var(--pico-color-cyan-850);
}

.pico-color-cyan-800 {
  color: var(--pico-color-cyan-800);
}

.pico-color-cyan-750 {
  color: var(--pico-color-cyan-750);
}

.pico-color-cyan-700 {
  color: var(--pico-color-cyan-700);
}

.pico-color-cyan-650 {
  color: var(--pico-color-cyan-650);
}

.pico-color-cyan-600 {
  color: var(--pico-color-cyan-600);
}

.pico-color-cyan-550 {
  color: var(--pico-color-cyan-550);
}

.pico-color-cyan-500 {
  color: var(--pico-color-cyan-500);
}

.pico-color-cyan-450 {
  color: var(--pico-color-cyan-450);
}

.pico-color-cyan-400 {
  color: var(--pico-color-cyan-400);
}

.pico-color-cyan-350 {
  color: var(--pico-color-cyan-350);
}

.pico-color-cyan-300 {
  color: var(--pico-color-cyan-300);
}

.pico-color-cyan-250 {
  color: var(--pico-color-cyan-250);
}

.pico-color-cyan-200 {
  color: var(--pico-color-cyan-200);
}

.pico-color-cyan-150 {
  color: var(--pico-color-cyan-150);
}

.pico-color-cyan-100 {
  color: var(--pico-color-cyan-100);
}

.pico-color-cyan-50 {
  color: var(--pico-color-cyan-50);
}

.pico-color-cyan {
  color: var(--pico-color-cyan);
}

.pico-color-jade-950 {
  color: var(--pico-color-jade-950);
}

.pico-color-jade-900 {
  color: var(--pico-color-jade-900);
}

.pico-color-jade-850 {
  color: var(--pico-color-jade-850);
}

.pico-color-jade-800 {
  color: var(--pico-color-jade-800);
}

.pico-color-jade-750 {
  color: var(--pico-color-jade-750);
}

.pico-color-jade-700 {
  color: var(--pico-color-jade-700);
}

.pico-color-jade-650 {
  color: var(--pico-color-jade-650);
}

.pico-color-jade-600 {
  color: var(--pico-color-jade-600);
}

.pico-color-jade-550 {
  color: var(--pico-color-jade-550);
}

.pico-color-jade-500 {
  color: var(--pico-color-jade-500);
}

.pico-color-jade-450 {
  color: var(--pico-color-jade-450);
}

.pico-color-jade-400 {
  color: var(--pico-color-jade-400);
}

.pico-color-jade-350 {
  color: var(--pico-color-jade-350);
}

.pico-color-jade-300 {
  color: var(--pico-color-jade-300);
}

.pico-color-jade-250 {
  color: var(--pico-color-jade-250);
}

.pico-color-jade-200 {
  color: var(--pico-color-jade-200);
}

.pico-color-jade-150 {
  color: var(--pico-color-jade-150);
}

.pico-color-jade-100 {
  color: var(--pico-color-jade-100);
}

.pico-color-jade-50 {
  color: var(--pico-color-jade-50);
}

.pico-color-jade {
  color: var(--pico-color-jade);
}

.pico-color-green-950 {
  color: var(--pico-color-green-950);
}

.pico-color-green-900 {
  color: var(--pico-color-green-900);
}

.pico-color-green-850 {
  color: var(--pico-color-green-850);
}

.pico-color-green-800 {
  color: var(--pico-color-green-800);
}

.pico-color-green-750 {
  color: var(--pico-color-green-750);
}

.pico-color-green-700 {
  color: var(--pico-color-green-700);
}

.pico-color-green-650 {
  color: var(--pico-color-green-650);
}

.pico-color-green-600 {
  color: var(--pico-color-green-600);
}

.pico-color-green-550 {
  color: var(--pico-color-green-550);
}

.pico-color-green-500 {
  color: var(--pico-color-green-500);
}

.pico-color-green-450 {
  color: var(--pico-color-green-450);
}

.pico-color-green-400 {
  color: var(--pico-color-green-400);
}

.pico-color-green-350 {
  color: var(--pico-color-green-350);
}

.pico-color-green-300 {
  color: var(--pico-color-green-300);
}

.pico-color-green-250 {
  color: var(--pico-color-green-250);
}

.pico-color-green-200 {
  color: var(--pico-color-green-200);
}

.pico-color-green-150 {
  color: var(--pico-color-green-150);
}

.pico-color-green-100 {
  color: var(--pico-color-green-100);
}

.pico-color-green-50 {
  color: var(--pico-color-green-50);
}

.pico-color-green {
  color: var(--pico-color-green);
}

.pico-color-lime-950 {
  color: var(--pico-color-lime-950);
}

.pico-color-lime-900 {
  color: var(--pico-color-lime-900);
}

.pico-color-lime-850 {
  color: var(--pico-color-lime-850);
}

.pico-color-lime-800 {
  color: var(--pico-color-lime-800);
}

.pico-color-lime-750 {
  color: var(--pico-color-lime-750);
}

.pico-color-lime-700 {
  color: var(--pico-color-lime-700);
}

.pico-color-lime-650 {
  color: var(--pico-color-lime-650);
}

.pico-color-lime-600 {
  color: var(--pico-color-lime-600);
}

.pico-color-lime-550 {
  color: var(--pico-color-lime-550);
}

.pico-color-lime-500 {
  color: var(--pico-color-lime-500);
}

.pico-color-lime-450 {
  color: var(--pico-color-lime-450);
}

.pico-color-lime-400 {
  color: var(--pico-color-lime-400);
}

.pico-color-lime-350 {
  color: var(--pico-color-lime-350);
}

.pico-color-lime-300 {
  color: var(--pico-color-lime-300);
}

.pico-color-lime-250 {
  color: var(--pico-color-lime-250);
}

.pico-color-lime-200 {
  color: var(--pico-color-lime-200);
}

.pico-color-lime-150 {
  color: var(--pico-color-lime-150);
}

.pico-color-lime-100 {
  color: var(--pico-color-lime-100);
}

.pico-color-lime-50 {
  color: var(--pico-color-lime-50);
}

.pico-color-lime {
  color: var(--pico-color-lime);
}

.pico-color-yellow-950 {
  color: var(--pico-color-yellow-950);
}

.pico-color-yellow-900 {
  color: var(--pico-color-yellow-900);
}

.pico-color-yellow-850 {
  color: var(--pico-color-yellow-850);
}

.pico-color-yellow-800 {
  color: var(--pico-color-yellow-800);
}

.pico-color-yellow-750 {
  color: var(--pico-color-yellow-750);
}

.pico-color-yellow-700 {
  color: var(--pico-color-yellow-700);
}

.pico-color-yellow-650 {
  color: var(--pico-color-yellow-650);
}

.pico-color-yellow-600 {
  color: var(--pico-color-yellow-600);
}

.pico-color-yellow-550 {
  color: var(--pico-color-yellow-550);
}

.pico-color-yellow-500 {
  color: var(--pico-color-yellow-500);
}

.pico-color-yellow-450 {
  color: var(--pico-color-yellow-450);
}

.pico-color-yellow-400 {
  color: var(--pico-color-yellow-400);
}

.pico-color-yellow-350 {
  color: var(--pico-color-yellow-350);
}

.pico-color-yellow-300 {
  color: var(--pico-color-yellow-300);
}

.pico-color-yellow-250 {
  color: var(--pico-color-yellow-250);
}

.pico-color-yellow-200 {
  color: var(--pico-color-yellow-200);
}

.pico-color-yellow-150 {
  color: var(--pico-color-yellow-150);
}

.pico-color-yellow-100 {
  color: var(--pico-color-yellow-100);
}

.pico-color-yellow-50 {
  color: var(--pico-color-yellow-50);
}

.pico-color-yellow {
  color: var(--pico-color-yellow);
}

.pico-color-amber-950 {
  color: var(--pico-color-amber-950);
}

.pico-color-amber-900 {
  color: var(--pico-color-amber-900);
}

.pico-color-amber-850 {
  color: var(--pico-color-amber-850);
}

.pico-color-amber-800 {
  color: var(--pico-color-amber-800);
}

.pico-color-amber-750 {
  color: var(--pico-color-amber-750);
}

.pico-color-amber-700 {
  color: var(--pico-color-amber-700);
}

.pico-color-amber-650 {
  color: var(--pico-color-amber-650);
}

.pico-color-amber-600 {
  color: var(--pico-color-amber-600);
}

.pico-color-amber-550 {
  color: var(--pico-color-amber-550);
}

.pico-color-amber-500 {
  color: var(--pico-color-amber-500);
}

.pico-color-amber-450 {
  color: var(--pico-color-amber-450);
}

.pico-color-amber-400 {
  color: var(--pico-color-amber-400);
}

.pico-color-amber-350 {
  color: var(--pico-color-amber-350);
}

.pico-color-amber-300 {
  color: var(--pico-color-amber-300);
}

.pico-color-amber-250 {
  color: var(--pico-color-amber-250);
}

.pico-color-amber-200 {
  color: var(--pico-color-amber-200);
}

.pico-color-amber-150 {
  color: var(--pico-color-amber-150);
}

.pico-color-amber-100 {
  color: var(--pico-color-amber-100);
}

.pico-color-amber-50 {
  color: var(--pico-color-amber-50);
}

.pico-color-amber {
  color: var(--pico-color-amber);
}

.pico-color-pumpkin-950 {
  color: var(--pico-color-pumpkin-950);
}

.pico-color-pumpkin-900 {
  color: var(--pico-color-pumpkin-900);
}

.pico-color-pumpkin-850 {
  color: var(--pico-color-pumpkin-850);
}

.pico-color-pumpkin-800 {
  color: var(--pico-color-pumpkin-800);
}

.pico-color-pumpkin-750 {
  color: var(--pico-color-pumpkin-750);
}

.pico-color-pumpkin-700 {
  color: var(--pico-color-pumpkin-700);
}

.pico-color-pumpkin-650 {
  color: var(--pico-color-pumpkin-650);
}

.pico-color-pumpkin-600 {
  color: var(--pico-color-pumpkin-600);
}

.pico-color-pumpkin-550 {
  color: var(--pico-color-pumpkin-550);
}

.pico-color-pumpkin-500 {
  color: var(--pico-color-pumpkin-500);
}

.pico-color-pumpkin-450 {
  color: var(--pico-color-pumpkin-450);
}

.pico-color-pumpkin-400 {
  color: var(--pico-color-pumpkin-400);
}

.pico-color-pumpkin-350 {
  color: var(--pico-color-pumpkin-350);
}

.pico-color-pumpkin-300 {
  color: var(--pico-color-pumpkin-300);
}

.pico-color-pumpkin-250 {
  color: var(--pico-color-pumpkin-250);
}

.pico-color-pumpkin-200 {
  color: var(--pico-color-pumpkin-200);
}

.pico-color-pumpkin-150 {
  color: var(--pico-color-pumpkin-150);
}

.pico-color-pumpkin-100 {
  color: var(--pico-color-pumpkin-100);
}

.pico-color-pumpkin-50 {
  color: var(--pico-color-pumpkin-50);
}

.pico-color-pumpkin {
  color: var(--pico-color-pumpkin);
}

.pico-color-orange-950 {
  color: var(--pico-color-orange-950);
}

.pico-color-orange-900 {
  color: var(--pico-color-orange-900);
}

.pico-color-orange-850 {
  color: var(--pico-color-orange-850);
}

.pico-color-orange-800 {
  color: var(--pico-color-orange-800);
}

.pico-color-orange-750 {
  color: var(--pico-color-orange-750);
}

.pico-color-orange-700 {
  color: var(--pico-color-orange-700);
}

.pico-color-orange-650 {
  color: var(--pico-color-orange-650);
}

.pico-color-orange-600 {
  color: var(--pico-color-orange-600);
}

.pico-color-orange-550 {
  color: var(--pico-color-orange-550);
}

.pico-color-orange-500 {
  color: var(--pico-color-orange-500);
}

.pico-color-orange-450 {
  color: var(--pico-color-orange-450);
}

.pico-color-orange-400 {
  color: var(--pico-color-orange-400);
}

.pico-color-orange-350 {
  color: var(--pico-color-orange-350);
}

.pico-color-orange-300 {
  color: var(--pico-color-orange-300);
}

.pico-color-orange-250 {
  color: var(--pico-color-orange-250);
}

.pico-color-orange-200 {
  color: var(--pico-color-orange-200);
}

.pico-color-orange-150 {
  color: var(--pico-color-orange-150);
}

.pico-color-orange-100 {
  color: var(--pico-color-orange-100);
}

.pico-color-orange-50 {
  color: var(--pico-color-orange-50);
}

.pico-color-orange {
  color: var(--pico-color-orange);
}

.pico-color-sand-950 {
  color: var(--pico-color-sand-950);
}

.pico-color-sand-900 {
  color: var(--pico-color-sand-900);
}

.pico-color-sand-850 {
  color: var(--pico-color-sand-850);
}

.pico-color-sand-800 {
  color: var(--pico-color-sand-800);
}

.pico-color-sand-750 {
  color: var(--pico-color-sand-750);
}

.pico-color-sand-700 {
  color: var(--pico-color-sand-700);
}

.pico-color-sand-650 {
  color: var(--pico-color-sand-650);
}

.pico-color-sand-600 {
  color: var(--pico-color-sand-600);
}

.pico-color-sand-550 {
  color: var(--pico-color-sand-550);
}

.pico-color-sand-500 {
  color: var(--pico-color-sand-500);
}

.pico-color-sand-450 {
  color: var(--pico-color-sand-450);
}

.pico-color-sand-400 {
  color: var(--pico-color-sand-400);
}

.pico-color-sand-350 {
  color: var(--pico-color-sand-350);
}

.pico-color-sand-300 {
  color: var(--pico-color-sand-300);
}

.pico-color-sand-250 {
  color: var(--pico-color-sand-250);
}

.pico-color-sand-200 {
  color: var(--pico-color-sand-200);
}

.pico-color-sand-150 {
  color: var(--pico-color-sand-150);
}

.pico-color-sand-100 {
  color: var(--pico-color-sand-100);
}

.pico-color-sand-50 {
  color: var(--pico-color-sand-50);
}

.pico-color-sand {
  color: var(--pico-color-sand);
}

.pico-color-grey-950 {
  color: var(--pico-color-grey-950);
}

.pico-color-grey-900 {
  color: var(--pico-color-grey-900);
}

.pico-color-grey-850 {
  color: var(--pico-color-grey-850);
}

.pico-color-grey-800 {
  color: var(--pico-color-grey-800);
}

.pico-color-grey-750 {
  color: var(--pico-color-grey-750);
}

.pico-color-grey-700 {
  color: var(--pico-color-grey-700);
}

.pico-color-grey-650 {
  color: var(--pico-color-grey-650);
}

.pico-color-grey-600 {
  color: var(--pico-color-grey-600);
}

.pico-color-grey-550 {
  color: var(--pico-color-grey-550);
}

.pico-color-grey-500 {
  color: var(--pico-color-grey-500);
}

.pico-color-grey-450 {
  color: var(--pico-color-grey-450);
}

.pico-color-grey-400 {
  color: var(--pico-color-grey-400);
}

.pico-color-grey-350 {
  color: var(--pico-color-grey-350);
}

.pico-color-grey-300 {
  color: var(--pico-color-grey-300);
}

.pico-color-grey-250 {
  color: var(--pico-color-grey-250);
}

.pico-color-grey-200 {
  color: var(--pico-color-grey-200);
}

.pico-color-grey-150 {
  color: var(--pico-color-grey-150);
}

.pico-color-grey-100 {
  color: var(--pico-color-grey-100);
}

.pico-color-grey-50 {
  color: var(--pico-color-grey-50);
}

.pico-color-grey {
  color: var(--pico-color-grey);
}

.pico-color-zinc-950 {
  color: var(--pico-color-zinc-950);
}

.pico-color-zinc-900 {
  color: var(--pico-color-zinc-900);
}

.pico-color-zinc-850 {
  color: var(--pico-color-zinc-850);
}

.pico-color-zinc-800 {
  color: var(--pico-color-zinc-800);
}

.pico-color-zinc-750 {
  color: var(--pico-color-zinc-750);
}

.pico-color-zinc-700 {
  color: var(--pico-color-zinc-700);
}

.pico-color-zinc-650 {
  color: var(--pico-color-zinc-650);
}

.pico-color-zinc-600 {
  color: var(--pico-color-zinc-600);
}

.pico-color-zinc-550 {
  color: var(--pico-color-zinc-550);
}

.pico-color-zinc-500 {
  color: var(--pico-color-zinc-500);
}

.pico-color-zinc-450 {
  color: var(--pico-color-zinc-450);
}

.pico-color-zinc-400 {
  color: var(--pico-color-zinc-400);
}

.pico-color-zinc-350 {
  color: var(--pico-color-zinc-350);
}

.pico-color-zinc-300 {
  color: var(--pico-color-zinc-300);
}

.pico-color-zinc-250 {
  color: var(--pico-color-zinc-250);
}

.pico-color-zinc-200 {
  color: var(--pico-color-zinc-200);
}

.pico-color-zinc-150 {
  color: var(--pico-color-zinc-150);
}

.pico-color-zinc-100 {
  color: var(--pico-color-zinc-100);
}

.pico-color-zinc-50 {
  color: var(--pico-color-zinc-50);
}

.pico-color-zinc {
  color: var(--pico-color-zinc);
}

.pico-color-slate-950 {
  color: var(--pico-color-slate-950);
}

.pico-color-slate-900 {
  color: var(--pico-color-slate-900);
}

.pico-color-slate-850 {
  color: var(--pico-color-slate-850);
}

.pico-color-slate-800 {
  color: var(--pico-color-slate-800);
}

.pico-color-slate-750 {
  color: var(--pico-color-slate-750);
}

.pico-color-slate-700 {
  color: var(--pico-color-slate-700);
}

.pico-color-slate-650 {
  color: var(--pico-color-slate-650);
}

.pico-color-slate-600 {
  color: var(--pico-color-slate-600);
}

.pico-color-slate-550 {
  color: var(--pico-color-slate-550);
}

.pico-color-slate-500 {
  color: var(--pico-color-slate-500);
}

.pico-color-slate-450 {
  color: var(--pico-color-slate-450);
}

.pico-color-slate-400 {
  color: var(--pico-color-slate-400);
}

.pico-color-slate-350 {
  color: var(--pico-color-slate-350);
}

.pico-color-slate-300 {
  color: var(--pico-color-slate-300);
}

.pico-color-slate-250 {
  color: var(--pico-color-slate-250);
}

.pico-color-slate-200 {
  color: var(--pico-color-slate-200);
}

.pico-color-slate-150 {
  color: var(--pico-color-slate-150);
}

.pico-color-slate-100 {
  color: var(--pico-color-slate-100);
}

.pico-color-slate-50 {
  color: var(--pico-color-slate-50);
}

.pico-color-slate {
  color: var(--pico-color-slate);
}

.pico-background-red-950 {
  background-color: var(--pico-color-red-950);
  color: var(--pico-color-light);
}

.pico-background-red-900 {
  background-color: var(--pico-color-red-900);
  color: var(--pico-color-light);
}

.pico-background-red-850 {
  background-color: var(--pico-color-red-850);
  color: var(--pico-color-light);
}

.pico-background-red-800 {
  background-color: var(--pico-color-red-800);
  color: var(--pico-color-light);
}

.pico-background-red-750 {
  background-color: var(--pico-color-red-750);
  color: var(--pico-color-light);
}

.pico-background-red-700 {
  background-color: var(--pico-color-red-700);
  color: var(--pico-color-light);
}

.pico-background-red-650 {
  background-color: var(--pico-color-red-650);
  color: var(--pico-color-light);
}

.pico-background-red-600 {
  background-color: var(--pico-color-red-600);
  color: var(--pico-color-light);
}

.pico-background-red-550 {
  background-color: var(--pico-color-red-550);
  color: var(--pico-color-light);
}

.pico-background-red-500 {
  background-color: var(--pico-color-red-500);
  color: var(--pico-color-light);
}

.pico-background-red-450 {
  background-color: var(--pico-color-red-450);
  color: var(--pico-color-light);
}

.pico-background-red-400 {
  background-color: var(--pico-color-red-400);
  color: var(--pico-color-dark);
}

.pico-background-red-350 {
  background-color: var(--pico-color-red-350);
  color: var(--pico-color-dark);
}

.pico-background-red-300 {
  background-color: var(--pico-color-red-300);
  color: var(--pico-color-dark);
}

.pico-background-red-250 {
  background-color: var(--pico-color-red-250);
  color: var(--pico-color-dark);
}

.pico-background-red-200 {
  background-color: var(--pico-color-red-200);
  color: var(--pico-color-dark);
}

.pico-background-red-150 {
  background-color: var(--pico-color-red-150);
  color: var(--pico-color-dark);
}

.pico-background-red-100 {
  background-color: var(--pico-color-red-100);
  color: var(--pico-color-dark);
}

.pico-background-red-50 {
  background-color: var(--pico-color-red-50);
  color: var(--pico-color-dark);
}

.pico-background-red {
  background-color: var(--pico-color-red);
  color: var(--pico-color-light);
}

.pico-background-pink-950 {
  background-color: var(--pico-color-pink-950);
  color: var(--pico-color-light);
}

.pico-background-pink-900 {
  background-color: var(--pico-color-pink-900);
  color: var(--pico-color-light);
}

.pico-background-pink-850 {
  background-color: var(--pico-color-pink-850);
  color: var(--pico-color-light);
}

.pico-background-pink-800 {
  background-color: var(--pico-color-pink-800);
  color: var(--pico-color-light);
}

.pico-background-pink-750 {
  background-color: var(--pico-color-pink-750);
  color: var(--pico-color-light);
}

.pico-background-pink-700 {
  background-color: var(--pico-color-pink-700);
  color: var(--pico-color-light);
}

.pico-background-pink-650 {
  background-color: var(--pico-color-pink-650);
  color: var(--pico-color-light);
}

.pico-background-pink-600 {
  background-color: var(--pico-color-pink-600);
  color: var(--pico-color-light);
}

.pico-background-pink-550 {
  background-color: var(--pico-color-pink-550);
  color: var(--pico-color-light);
}

.pico-background-pink-500 {
  background-color: var(--pico-color-pink-500);
  color: var(--pico-color-light);
}

.pico-background-pink-450 {
  background-color: var(--pico-color-pink-450);
  color: var(--pico-color-light);
}

.pico-background-pink-400 {
  background-color: var(--pico-color-pink-400);
  color: var(--pico-color-dark);
}

.pico-background-pink-350 {
  background-color: var(--pico-color-pink-350);
  color: var(--pico-color-dark);
}

.pico-background-pink-300 {
  background-color: var(--pico-color-pink-300);
  color: var(--pico-color-dark);
}

.pico-background-pink-250 {
  background-color: var(--pico-color-pink-250);
  color: var(--pico-color-dark);
}

.pico-background-pink-200 {
  background-color: var(--pico-color-pink-200);
  color: var(--pico-color-dark);
}

.pico-background-pink-150 {
  background-color: var(--pico-color-pink-150);
  color: var(--pico-color-dark);
}

.pico-background-pink-100 {
  background-color: var(--pico-color-pink-100);
  color: var(--pico-color-dark);
}

.pico-background-pink-50 {
  background-color: var(--pico-color-pink-50);
  color: var(--pico-color-dark);
}

.pico-background-pink {
  background-color: var(--pico-color-pink);
  color: var(--pico-color-light);
}

.pico-background-fuchsia-950 {
  background-color: var(--pico-color-fuchsia-950);
  color: var(--pico-color-light);
}

.pico-background-fuchsia-900 {
  background-color: var(--pico-color-fuchsia-900);
  color: var(--pico-color-light);
}

.pico-background-fuchsia-850 {
  background-color: var(--pico-color-fuchsia-850);
  color: var(--pico-color-light);
}

.pico-background-fuchsia-800 {
  background-color: var(--pico-color-fuchsia-800);
  color: var(--pico-color-light);
}

.pico-background-fuchsia-750 {
  background-color: var(--pico-color-fuchsia-750);
  color: var(--pico-color-light);
}

.pico-background-fuchsia-700 {
  background-color: var(--pico-color-fuchsia-700);
  color: var(--pico-color-light);
}

.pico-background-fuchsia-650 {
  background-color: var(--pico-color-fuchsia-650);
  color: var(--pico-color-light);
}

.pico-background-fuchsia-600 {
  background-color: var(--pico-color-fuchsia-600);
  color: var(--pico-color-light);
}

.pico-background-fuchsia-550 {
  background-color: var(--pico-color-fuchsia-550);
  color: var(--pico-color-light);
}

.pico-background-fuchsia-500 {
  background-color: var(--pico-color-fuchsia-500);
  color: var(--pico-color-light);
}

.pico-background-fuchsia-450 {
  background-color: var(--pico-color-fuchsia-450);
  color: var(--pico-color-light);
}

.pico-background-fuchsia-400 {
  background-color: var(--pico-color-fuchsia-400);
  color: var(--pico-color-dark);
}

.pico-background-fuchsia-350 {
  background-color: var(--pico-color-fuchsia-350);
  color: var(--pico-color-dark);
}

.pico-background-fuchsia-300 {
  background-color: var(--pico-color-fuchsia-300);
  color: var(--pico-color-dark);
}

.pico-background-fuchsia-250 {
  background-color: var(--pico-color-fuchsia-250);
  color: var(--pico-color-dark);
}

.pico-background-fuchsia-200 {
  background-color: var(--pico-color-fuchsia-200);
  color: var(--pico-color-dark);
}

.pico-background-fuchsia-150 {
  background-color: var(--pico-color-fuchsia-150);
  color: var(--pico-color-dark);
}

.pico-background-fuchsia-100 {
  background-color: var(--pico-color-fuchsia-100);
  color: var(--pico-color-dark);
}

.pico-background-fuchsia-50 {
  background-color: var(--pico-color-fuchsia-50);
  color: var(--pico-color-dark);
}

.pico-background-fuchsia {
  background-color: var(--pico-color-fuchsia);
  color: var(--pico-color-light);
}

.pico-background-purple-950 {
  background-color: var(--pico-color-purple-950);
  color: var(--pico-color-light);
}

.pico-background-purple-900 {
  background-color: var(--pico-color-purple-900);
  color: var(--pico-color-light);
}

.pico-background-purple-850 {
  background-color: var(--pico-color-purple-850);
  color: var(--pico-color-light);
}

.pico-background-purple-800 {
  background-color: var(--pico-color-purple-800);
  color: var(--pico-color-light);
}

.pico-background-purple-750 {
  background-color: var(--pico-color-purple-750);
  color: var(--pico-color-light);
}

.pico-background-purple-700 {
  background-color: var(--pico-color-purple-700);
  color: var(--pico-color-light);
}

.pico-background-purple-650 {
  background-color: var(--pico-color-purple-650);
  color: var(--pico-color-light);
}

.pico-background-purple-600 {
  background-color: var(--pico-color-purple-600);
  color: var(--pico-color-light);
}

.pico-background-purple-550 {
  background-color: var(--pico-color-purple-550);
  color: var(--pico-color-light);
}

.pico-background-purple-500 {
  background-color: var(--pico-color-purple-500);
  color: var(--pico-color-light);
}

.pico-background-purple-450 {
  background-color: var(--pico-color-purple-450);
  color: var(--pico-color-dark);
}

.pico-background-purple-400 {
  background-color: var(--pico-color-purple-400);
  color: var(--pico-color-dark);
}

.pico-background-purple-350 {
  background-color: var(--pico-color-purple-350);
  color: var(--pico-color-dark);
}

.pico-background-purple-300 {
  background-color: var(--pico-color-purple-300);
  color: var(--pico-color-dark);
}

.pico-background-purple-250 {
  background-color: var(--pico-color-purple-250);
  color: var(--pico-color-dark);
}

.pico-background-purple-200 {
  background-color: var(--pico-color-purple-200);
  color: var(--pico-color-dark);
}

.pico-background-purple-150 {
  background-color: var(--pico-color-purple-150);
  color: var(--pico-color-dark);
}

.pico-background-purple-100 {
  background-color: var(--pico-color-purple-100);
  color: var(--pico-color-dark);
}

.pico-background-purple-50 {
  background-color: var(--pico-color-purple-50);
  color: var(--pico-color-dark);
}

.pico-background-purple {
  background-color: var(--pico-color-purple);
  color: var(--pico-color-light);
}

.pico-background-violet-950 {
  background-color: var(--pico-color-violet-950);
  color: var(--pico-color-light);
}

.pico-background-violet-900 {
  background-color: var(--pico-color-violet-900);
  color: var(--pico-color-light);
}

.pico-background-violet-850 {
  background-color: var(--pico-color-violet-850);
  color: var(--pico-color-light);
}

.pico-background-violet-800 {
  background-color: var(--pico-color-violet-800);
  color: var(--pico-color-light);
}

.pico-background-violet-750 {
  background-color: var(--pico-color-violet-750);
  color: var(--pico-color-light);
}

.pico-background-violet-700 {
  background-color: var(--pico-color-violet-700);
  color: var(--pico-color-light);
}

.pico-background-violet-650 {
  background-color: var(--pico-color-violet-650);
  color: var(--pico-color-light);
}

.pico-background-violet-600 {
  background-color: var(--pico-color-violet-600);
  color: var(--pico-color-light);
}

.pico-background-violet-550 {
  background-color: var(--pico-color-violet-550);
  color: var(--pico-color-light);
}

.pico-background-violet-500 {
  background-color: var(--pico-color-violet-500);
  color: var(--pico-color-light);
}

.pico-background-violet-450 {
  background-color: var(--pico-color-violet-450);
  color: var(--pico-color-dark);
}

.pico-background-violet-400 {
  background-color: var(--pico-color-violet-400);
  color: var(--pico-color-dark);
}

.pico-background-violet-350 {
  background-color: var(--pico-color-violet-350);
  color: var(--pico-color-dark);
}

.pico-background-violet-300 {
  background-color: var(--pico-color-violet-300);
  color: var(--pico-color-dark);
}

.pico-background-violet-250 {
  background-color: var(--pico-color-violet-250);
  color: var(--pico-color-dark);
}

.pico-background-violet-200 {
  background-color: var(--pico-color-violet-200);
  color: var(--pico-color-dark);
}

.pico-background-violet-150 {
  background-color: var(--pico-color-violet-150);
  color: var(--pico-color-dark);
}

.pico-background-violet-100 {
  background-color: var(--pico-color-violet-100);
  color: var(--pico-color-dark);
}

.pico-background-violet-50 {
  background-color: var(--pico-color-violet-50);
  color: var(--pico-color-dark);
}

.pico-background-violet {
  background-color: var(--pico-color-violet);
  color: var(--pico-color-light);
}

.pico-background-indigo-950 {
  background-color: var(--pico-color-indigo-950);
  color: var(--pico-color-light);
}

.pico-background-indigo-900 {
  background-color: var(--pico-color-indigo-900);
  color: var(--pico-color-light);
}

.pico-background-indigo-850 {
  background-color: var(--pico-color-indigo-850);
  color: var(--pico-color-light);
}

.pico-background-indigo-800 {
  background-color: var(--pico-color-indigo-800);
  color: var(--pico-color-light);
}

.pico-background-indigo-750 {
  background-color: var(--pico-color-indigo-750);
  color: var(--pico-color-light);
}

.pico-background-indigo-700 {
  background-color: var(--pico-color-indigo-700);
  color: var(--pico-color-light);
}

.pico-background-indigo-650 {
  background-color: var(--pico-color-indigo-650);
  color: var(--pico-color-light);
}

.pico-background-indigo-600 {
  background-color: var(--pico-color-indigo-600);
  color: var(--pico-color-light);
}

.pico-background-indigo-550 {
  background-color: var(--pico-color-indigo-550);
  color: var(--pico-color-light);
}

.pico-background-indigo-500 {
  background-color: var(--pico-color-indigo-500);
  color: var(--pico-color-light);
}

.pico-background-indigo-450 {
  background-color: var(--pico-color-indigo-450);
  color: var(--pico-color-dark);
}

.pico-background-indigo-400 {
  background-color: var(--pico-color-indigo-400);
  color: var(--pico-color-dark);
}

.pico-background-indigo-350 {
  background-color: var(--pico-color-indigo-350);
  color: var(--pico-color-dark);
}

.pico-background-indigo-300 {
  background-color: var(--pico-color-indigo-300);
  color: var(--pico-color-dark);
}

.pico-background-indigo-250 {
  background-color: var(--pico-color-indigo-250);
  color: var(--pico-color-dark);
}

.pico-background-indigo-200 {
  background-color: var(--pico-color-indigo-200);
  color: var(--pico-color-dark);
}

.pico-background-indigo-150 {
  background-color: var(--pico-color-indigo-150);
  color: var(--pico-color-dark);
}

.pico-background-indigo-100 {
  background-color: var(--pico-color-indigo-100);
  color: var(--pico-color-dark);
}

.pico-background-indigo-50 {
  background-color: var(--pico-color-indigo-50);
  color: var(--pico-color-dark);
}

.pico-background-indigo {
  background-color: var(--pico-color-indigo);
  color: var(--pico-color-light);
}

.pico-background-blue-950 {
  background-color: var(--pico-color-blue-950);
  color: var(--pico-color-light);
}

.pico-background-blue-900 {
  background-color: var(--pico-color-blue-900);
  color: var(--pico-color-light);
}

.pico-background-blue-850 {
  background-color: var(--pico-color-blue-850);
  color: var(--pico-color-light);
}

.pico-background-blue-800 {
  background-color: var(--pico-color-blue-800);
  color: var(--pico-color-light);
}

.pico-background-blue-750 {
  background-color: var(--pico-color-blue-750);
  color: var(--pico-color-light);
}

.pico-background-blue-700 {
  background-color: var(--pico-color-blue-700);
  color: var(--pico-color-light);
}

.pico-background-blue-650 {
  background-color: var(--pico-color-blue-650);
  color: var(--pico-color-light);
}

.pico-background-blue-600 {
  background-color: var(--pico-color-blue-600);
  color: var(--pico-color-light);
}

.pico-background-blue-550 {
  background-color: var(--pico-color-blue-550);
  color: var(--pico-color-light);
}

.pico-background-blue-500 {
  background-color: var(--pico-color-blue-500);
  color: var(--pico-color-light);
}

.pico-background-blue-450 {
  background-color: var(--pico-color-blue-450);
  color: var(--pico-color-dark);
}

.pico-background-blue-400 {
  background-color: var(--pico-color-blue-400);
  color: var(--pico-color-dark);
}

.pico-background-blue-350 {
  background-color: var(--pico-color-blue-350);
  color: var(--pico-color-dark);
}

.pico-background-blue-300 {
  background-color: var(--pico-color-blue-300);
  color: var(--pico-color-dark);
}

.pico-background-blue-250 {
  background-color: var(--pico-color-blue-250);
  color: var(--pico-color-dark);
}

.pico-background-blue-200 {
  background-color: var(--pico-color-blue-200);
  color: var(--pico-color-dark);
}

.pico-background-blue-150 {
  background-color: var(--pico-color-blue-150);
  color: var(--pico-color-dark);
}

.pico-background-blue-100 {
  background-color: var(--pico-color-blue-100);
  color: var(--pico-color-dark);
}

.pico-background-blue-50 {
  background-color: var(--pico-color-blue-50);
  color: var(--pico-color-dark);
}

.pico-background-blue {
  background-color: var(--pico-color-blue);
  color: var(--pico-color-light);
}

.pico-background-azure-950 {
  background-color: var(--pico-color-azure-950);
  color: var(--pico-color-light);
}

.pico-background-azure-900 {
  background-color: var(--pico-color-azure-900);
  color: var(--pico-color-light);
}

.pico-background-azure-850 {
  background-color: var(--pico-color-azure-850);
  color: var(--pico-color-light);
}

.pico-background-azure-800 {
  background-color: var(--pico-color-azure-800);
  color: var(--pico-color-light);
}

.pico-background-azure-750 {
  background-color: var(--pico-color-azure-750);
  color: var(--pico-color-light);
}

.pico-background-azure-700 {
  background-color: var(--pico-color-azure-700);
  color: var(--pico-color-light);
}

.pico-background-azure-650 {
  background-color: var(--pico-color-azure-650);
  color: var(--pico-color-light);
}

.pico-background-azure-600 {
  background-color: var(--pico-color-azure-600);
  color: var(--pico-color-light);
}

.pico-background-azure-550 {
  background-color: var(--pico-color-azure-550);
  color: var(--pico-color-light);
}

.pico-background-azure-500 {
  background-color: var(--pico-color-azure-500);
  color: var(--pico-color-light);
}

.pico-background-azure-450 {
  background-color: var(--pico-color-azure-450);
  color: var(--pico-color-light);
}

.pico-background-azure-400 {
  background-color: var(--pico-color-azure-400);
  color: var(--pico-color-light);
}

.pico-background-azure-350 {
  background-color: var(--pico-color-azure-350);
  color: var(--pico-color-dark);
}

.pico-background-azure-300 {
  background-color: var(--pico-color-azure-300);
  color: var(--pico-color-dark);
}

.pico-background-azure-250 {
  background-color: var(--pico-color-azure-250);
  color: var(--pico-color-dark);
}

.pico-background-azure-200 {
  background-color: var(--pico-color-azure-200);
  color: var(--pico-color-dark);
}

.pico-background-azure-150 {
  background-color: var(--pico-color-azure-150);
  color: var(--pico-color-dark);
}

.pico-background-azure-100 {
  background-color: var(--pico-color-azure-100);
  color: var(--pico-color-dark);
}

.pico-background-azure-50 {
  background-color: var(--pico-color-azure-50);
  color: var(--pico-color-dark);
}

.pico-background-azure {
  background-color: var(--pico-color-azure);
  color: var(--pico-color-light);
}

.pico-background-cyan-950 {
  background-color: var(--pico-color-cyan-950);
  color: var(--pico-color-light);
}

.pico-background-cyan-900 {
  background-color: var(--pico-color-cyan-900);
  color: var(--pico-color-light);
}

.pico-background-cyan-850 {
  background-color: var(--pico-color-cyan-850);
  color: var(--pico-color-light);
}

.pico-background-cyan-800 {
  background-color: var(--pico-color-cyan-800);
  color: var(--pico-color-light);
}

.pico-background-cyan-750 {
  background-color: var(--pico-color-cyan-750);
  color: var(--pico-color-light);
}

.pico-background-cyan-700 {
  background-color: var(--pico-color-cyan-700);
  color: var(--pico-color-light);
}

.pico-background-cyan-650 {
  background-color: var(--pico-color-cyan-650);
  color: var(--pico-color-light);
}

.pico-background-cyan-600 {
  background-color: var(--pico-color-cyan-600);
  color: var(--pico-color-light);
}

.pico-background-cyan-550 {
  background-color: var(--pico-color-cyan-550);
  color: var(--pico-color-light);
}

.pico-background-cyan-500 {
  background-color: var(--pico-color-cyan-500);
  color: var(--pico-color-light);
}

.pico-background-cyan-450 {
  background-color: var(--pico-color-cyan-450);
  color: var(--pico-color-light);
}

.pico-background-cyan-400 {
  background-color: var(--pico-color-cyan-400);
  color: var(--pico-color-light);
}

.pico-background-cyan-350 {
  background-color: var(--pico-color-cyan-350);
  color: var(--pico-color-light);
}

.pico-background-cyan-300 {
  background-color: var(--pico-color-cyan-300);
  color: var(--pico-color-dark);
}

.pico-background-cyan-250 {
  background-color: var(--pico-color-cyan-250);
  color: var(--pico-color-dark);
}

.pico-background-cyan-200 {
  background-color: var(--pico-color-cyan-200);
  color: var(--pico-color-dark);
}

.pico-background-cyan-150 {
  background-color: var(--pico-color-cyan-150);
  color: var(--pico-color-dark);
}

.pico-background-cyan-100 {
  background-color: var(--pico-color-cyan-100);
  color: var(--pico-color-dark);
}

.pico-background-cyan-50 {
  background-color: var(--pico-color-cyan-50);
  color: var(--pico-color-dark);
}

.pico-background-cyan {
  background-color: var(--pico-color-cyan);
  color: var(--pico-color-light);
}

.pico-background-jade-950 {
  background-color: var(--pico-color-jade-950);
  color: var(--pico-color-light);
}

.pico-background-jade-900 {
  background-color: var(--pico-color-jade-900);
  color: var(--pico-color-light);
}

.pico-background-jade-850 {
  background-color: var(--pico-color-jade-850);
  color: var(--pico-color-light);
}

.pico-background-jade-800 {
  background-color: var(--pico-color-jade-800);
  color: var(--pico-color-light);
}

.pico-background-jade-750 {
  background-color: var(--pico-color-jade-750);
  color: var(--pico-color-light);
}

.pico-background-jade-700 {
  background-color: var(--pico-color-jade-700);
  color: var(--pico-color-light);
}

.pico-background-jade-650 {
  background-color: var(--pico-color-jade-650);
  color: var(--pico-color-light);
}

.pico-background-jade-600 {
  background-color: var(--pico-color-jade-600);
  color: var(--pico-color-light);
}

.pico-background-jade-550 {
  background-color: var(--pico-color-jade-550);
  color: var(--pico-color-light);
}

.pico-background-jade-500 {
  background-color: var(--pico-color-jade-500);
  color: var(--pico-color-light);
}

.pico-background-jade-450 {
  background-color: var(--pico-color-jade-450);
  color: var(--pico-color-light);
}

.pico-background-jade-400 {
  background-color: var(--pico-color-jade-400);
  color: var(--pico-color-light);
}

.pico-background-jade-350 {
  background-color: var(--pico-color-jade-350);
  color: var(--pico-color-light);
}

.pico-background-jade-300 {
  background-color: var(--pico-color-jade-300);
  color: var(--pico-color-dark);
}

.pico-background-jade-250 {
  background-color: var(--pico-color-jade-250);
  color: var(--pico-color-dark);
}

.pico-background-jade-200 {
  background-color: var(--pico-color-jade-200);
  color: var(--pico-color-dark);
}

.pico-background-jade-150 {
  background-color: var(--pico-color-jade-150);
  color: var(--pico-color-dark);
}

.pico-background-jade-100 {
  background-color: var(--pico-color-jade-100);
  color: var(--pico-color-dark);
}

.pico-background-jade-50 {
  background-color: var(--pico-color-jade-50);
  color: var(--pico-color-dark);
}

.pico-background-jade {
  background-color: var(--pico-color-jade);
  color: var(--pico-color-light);
}

.pico-background-green-950 {
  background-color: var(--pico-color-green-950);
  color: var(--pico-color-light);
}

.pico-background-green-900 {
  background-color: var(--pico-color-green-900);
  color: var(--pico-color-light);
}

.pico-background-green-850 {
  background-color: var(--pico-color-green-850);
  color: var(--pico-color-light);
}

.pico-background-green-800 {
  background-color: var(--pico-color-green-800);
  color: var(--pico-color-light);
}

.pico-background-green-750 {
  background-color: var(--pico-color-green-750);
  color: var(--pico-color-light);
}

.pico-background-green-700 {
  background-color: var(--pico-color-green-700);
  color: var(--pico-color-light);
}

.pico-background-green-650 {
  background-color: var(--pico-color-green-650);
  color: var(--pico-color-light);
}

.pico-background-green-600 {
  background-color: var(--pico-color-green-600);
  color: var(--pico-color-light);
}

.pico-background-green-550 {
  background-color: var(--pico-color-green-550);
  color: var(--pico-color-light);
}

.pico-background-green-500 {
  background-color: var(--pico-color-green-500);
  color: var(--pico-color-light);
}

.pico-background-green-450 {
  background-color: var(--pico-color-green-450);
  color: var(--pico-color-light);
}

.pico-background-green-400 {
  background-color: var(--pico-color-green-400);
  color: var(--pico-color-light);
}

.pico-background-green-350 {
  background-color: var(--pico-color-green-350);
  color: var(--pico-color-dark);
}

.pico-background-green-300 {
  background-color: var(--pico-color-green-300);
  color: var(--pico-color-dark);
}

.pico-background-green-250 {
  background-color: var(--pico-color-green-250);
  color: var(--pico-color-dark);
}

.pico-background-green-200 {
  background-color: var(--pico-color-green-200);
  color: var(--pico-color-dark);
}

.pico-background-green-150 {
  background-color: var(--pico-color-green-150);
  color: var(--pico-color-dark);
}

.pico-background-green-100 {
  background-color: var(--pico-color-green-100);
  color: var(--pico-color-dark);
}

.pico-background-green-50 {
  background-color: var(--pico-color-green-50);
  color: var(--pico-color-dark);
}

.pico-background-green {
  background-color: var(--pico-color-green);
  color: var(--pico-color-light);
}

.pico-background-lime-950 {
  background-color: var(--pico-color-lime-950);
  color: var(--pico-color-light);
}

.pico-background-lime-900 {
  background-color: var(--pico-color-lime-900);
  color: var(--pico-color-light);
}

.pico-background-lime-850 {
  background-color: var(--pico-color-lime-850);
  color: var(--pico-color-light);
}

.pico-background-lime-800 {
  background-color: var(--pico-color-lime-800);
  color: var(--pico-color-light);
}

.pico-background-lime-750 {
  background-color: var(--pico-color-lime-750);
  color: var(--pico-color-light);
}

.pico-background-lime-700 {
  background-color: var(--pico-color-lime-700);
  color: var(--pico-color-light);
}

.pico-background-lime-650 {
  background-color: var(--pico-color-lime-650);
  color: var(--pico-color-light);
}

.pico-background-lime-600 {
  background-color: var(--pico-color-lime-600);
  color: var(--pico-color-light);
}

.pico-background-lime-550 {
  background-color: var(--pico-color-lime-550);
  color: var(--pico-color-light);
}

.pico-background-lime-500 {
  background-color: var(--pico-color-lime-500);
  color: var(--pico-color-light);
}

.pico-background-lime-450 {
  background-color: var(--pico-color-lime-450);
  color: var(--pico-color-light);
}

.pico-background-lime-400 {
  background-color: var(--pico-color-lime-400);
  color: var(--pico-color-light);
}

.pico-background-lime-350 {
  background-color: var(--pico-color-lime-350);
  color: var(--pico-color-dark);
}

.pico-background-lime-300 {
  background-color: var(--pico-color-lime-300);
  color: var(--pico-color-dark);
}

.pico-background-lime-250 {
  background-color: var(--pico-color-lime-250);
  color: var(--pico-color-dark);
}

.pico-background-lime-200 {
  background-color: var(--pico-color-lime-200);
  color: var(--pico-color-dark);
}

.pico-background-lime-150 {
  background-color: var(--pico-color-lime-150);
  color: var(--pico-color-dark);
}

.pico-background-lime-100 {
  background-color: var(--pico-color-lime-100);
  color: var(--pico-color-dark);
}

.pico-background-lime-50 {
  background-color: var(--pico-color-lime-50);
  color: var(--pico-color-dark);
}

.pico-background-lime {
  background-color: var(--pico-color-lime);
  color: var(--pico-color-dark);
}

.pico-background-yellow-950 {
  background-color: var(--pico-color-yellow-950);
  color: var(--pico-color-light);
}

.pico-background-yellow-900 {
  background-color: var(--pico-color-yellow-900);
  color: var(--pico-color-light);
}

.pico-background-yellow-850 {
  background-color: var(--pico-color-yellow-850);
  color: var(--pico-color-light);
}

.pico-background-yellow-800 {
  background-color: var(--pico-color-yellow-800);
  color: var(--pico-color-light);
}

.pico-background-yellow-750 {
  background-color: var(--pico-color-yellow-750);
  color: var(--pico-color-light);
}

.pico-background-yellow-700 {
  background-color: var(--pico-color-yellow-700);
  color: var(--pico-color-light);
}

.pico-background-yellow-650 {
  background-color: var(--pico-color-yellow-650);
  color: var(--pico-color-light);
}

.pico-background-yellow-600 {
  background-color: var(--pico-color-yellow-600);
  color: var(--pico-color-light);
}

.pico-background-yellow-550 {
  background-color: var(--pico-color-yellow-550);
  color: var(--pico-color-light);
}

.pico-background-yellow-500 {
  background-color: var(--pico-color-yellow-500);
  color: var(--pico-color-light);
}

.pico-background-yellow-450 {
  background-color: var(--pico-color-yellow-450);
  color: var(--pico-color-light);
}

.pico-background-yellow-400 {
  background-color: var(--pico-color-yellow-400);
  color: var(--pico-color-dark);
}

.pico-background-yellow-350 {
  background-color: var(--pico-color-yellow-350);
  color: var(--pico-color-dark);
}

.pico-background-yellow-300 {
  background-color: var(--pico-color-yellow-300);
  color: var(--pico-color-dark);
}

.pico-background-yellow-250 {
  background-color: var(--pico-color-yellow-250);
  color: var(--pico-color-dark);
}

.pico-background-yellow-200 {
  background-color: var(--pico-color-yellow-200);
  color: var(--pico-color-dark);
}

.pico-background-yellow-150 {
  background-color: var(--pico-color-yellow-150);
  color: var(--pico-color-dark);
}

.pico-background-yellow-100 {
  background-color: var(--pico-color-yellow-100);
  color: var(--pico-color-dark);
}

.pico-background-yellow-50 {
  background-color: var(--pico-color-yellow-50);
  color: var(--pico-color-dark);
}

.pico-background-yellow {
  background-color: var(--pico-color-yellow);
  color: var(--pico-color-dark);
}

.pico-background-amber-950 {
  background-color: var(--pico-color-amber-950);
  color: var(--pico-color-light);
}

.pico-background-amber-900 {
  background-color: var(--pico-color-amber-900);
  color: var(--pico-color-light);
}

.pico-background-amber-850 {
  background-color: var(--pico-color-amber-850);
  color: var(--pico-color-light);
}

.pico-background-amber-800 {
  background-color: var(--pico-color-amber-800);
  color: var(--pico-color-light);
}

.pico-background-amber-750 {
  background-color: var(--pico-color-amber-750);
  color: var(--pico-color-light);
}

.pico-background-amber-700 {
  background-color: var(--pico-color-amber-700);
  color: var(--pico-color-light);
}

.pico-background-amber-650 {
  background-color: var(--pico-color-amber-650);
  color: var(--pico-color-light);
}

.pico-background-amber-600 {
  background-color: var(--pico-color-amber-600);
  color: var(--pico-color-light);
}

.pico-background-amber-550 {
  background-color: var(--pico-color-amber-550);
  color: var(--pico-color-light);
}

.pico-background-amber-500 {
  background-color: var(--pico-color-amber-500);
  color: var(--pico-color-light);
}

.pico-background-amber-450 {
  background-color: var(--pico-color-amber-450);
  color: var(--pico-color-light);
}

.pico-background-amber-400 {
  background-color: var(--pico-color-amber-400);
  color: var(--pico-color-dark);
}

.pico-background-amber-350 {
  background-color: var(--pico-color-amber-350);
  color: var(--pico-color-dark);
}

.pico-background-amber-300 {
  background-color: var(--pico-color-amber-300);
  color: var(--pico-color-dark);
}

.pico-background-amber-250 {
  background-color: var(--pico-color-amber-250);
  color: var(--pico-color-dark);
}

.pico-background-amber-200 {
  background-color: var(--pico-color-amber-200);
  color: var(--pico-color-dark);
}

.pico-background-amber-150 {
  background-color: var(--pico-color-amber-150);
  color: var(--pico-color-dark);
}

.pico-background-amber-100 {
  background-color: var(--pico-color-amber-100);
  color: var(--pico-color-dark);
}

.pico-background-amber-50 {
  background-color: var(--pico-color-amber-50);
  color: var(--pico-color-dark);
}

.pico-background-amber {
  background-color: var(--pico-color-amber);
  color: var(--pico-color-dark);
}

.pico-background-pumpkin-950 {
  background-color: var(--pico-color-pumpkin-950);
  color: var(--pico-color-light);
}

.pico-background-pumpkin-900 {
  background-color: var(--pico-color-pumpkin-900);
  color: var(--pico-color-light);
}

.pico-background-pumpkin-850 {
  background-color: var(--pico-color-pumpkin-850);
  color: var(--pico-color-light);
}

.pico-background-pumpkin-800 {
  background-color: var(--pico-color-pumpkin-800);
  color: var(--pico-color-light);
}

.pico-background-pumpkin-750 {
  background-color: var(--pico-color-pumpkin-750);
  color: var(--pico-color-light);
}

.pico-background-pumpkin-700 {
  background-color: var(--pico-color-pumpkin-700);
  color: var(--pico-color-light);
}

.pico-background-pumpkin-650 {
  background-color: var(--pico-color-pumpkin-650);
  color: var(--pico-color-light);
}

.pico-background-pumpkin-600 {
  background-color: var(--pico-color-pumpkin-600);
  color: var(--pico-color-light);
}

.pico-background-pumpkin-550 {
  background-color: var(--pico-color-pumpkin-550);
  color: var(--pico-color-light);
}

.pico-background-pumpkin-500 {
  background-color: var(--pico-color-pumpkin-500);
  color: var(--pico-color-light);
}

.pico-background-pumpkin-450 {
  background-color: var(--pico-color-pumpkin-450);
  color: var(--pico-color-light);
}

.pico-background-pumpkin-400 {
  background-color: var(--pico-color-pumpkin-400);
  color: var(--pico-color-dark);
}

.pico-background-pumpkin-350 {
  background-color: var(--pico-color-pumpkin-350);
  color: var(--pico-color-dark);
}

.pico-background-pumpkin-300 {
  background-color: var(--pico-color-pumpkin-300);
  color: var(--pico-color-dark);
}

.pico-background-pumpkin-250 {
  background-color: var(--pico-color-pumpkin-250);
  color: var(--pico-color-dark);
}

.pico-background-pumpkin-200 {
  background-color: var(--pico-color-pumpkin-200);
  color: var(--pico-color-dark);
}

.pico-background-pumpkin-150 {
  background-color: var(--pico-color-pumpkin-150);
  color: var(--pico-color-dark);
}

.pico-background-pumpkin-100 {
  background-color: var(--pico-color-pumpkin-100);
  color: var(--pico-color-dark);
}

.pico-background-pumpkin-50 {
  background-color: var(--pico-color-pumpkin-50);
  color: var(--pico-color-dark);
}

.pico-background-pumpkin {
  background-color: var(--pico-color-pumpkin);
  color: var(--pico-color-dark);
}

.pico-background-orange-950 {
  background-color: var(--pico-color-orange-950);
  color: var(--pico-color-light);
}

.pico-background-orange-900 {
  background-color: var(--pico-color-orange-900);
  color: var(--pico-color-light);
}

.pico-background-orange-850 {
  background-color: var(--pico-color-orange-850);
  color: var(--pico-color-light);
}

.pico-background-orange-800 {
  background-color: var(--pico-color-orange-800);
  color: var(--pico-color-light);
}

.pico-background-orange-750 {
  background-color: var(--pico-color-orange-750);
  color: var(--pico-color-light);
}

.pico-background-orange-700 {
  background-color: var(--pico-color-orange-700);
  color: var(--pico-color-light);
}

.pico-background-orange-650 {
  background-color: var(--pico-color-orange-650);
  color: var(--pico-color-light);
}

.pico-background-orange-600 {
  background-color: var(--pico-color-orange-600);
  color: var(--pico-color-light);
}

.pico-background-orange-550 {
  background-color: var(--pico-color-orange-550);
  color: var(--pico-color-light);
}

.pico-background-orange-500 {
  background-color: var(--pico-color-orange-500);
  color: var(--pico-color-light);
}

.pico-background-orange-450 {
  background-color: var(--pico-color-orange-450);
  color: var(--pico-color-light);
}

.pico-background-orange-400 {
  background-color: var(--pico-color-orange-400);
  color: var(--pico-color-dark);
}

.pico-background-orange-350 {
  background-color: var(--pico-color-orange-350);
  color: var(--pico-color-dark);
}

.pico-background-orange-300 {
  background-color: var(--pico-color-orange-300);
  color: var(--pico-color-dark);
}

.pico-background-orange-250 {
  background-color: var(--pico-color-orange-250);
  color: var(--pico-color-dark);
}

.pico-background-orange-200 {
  background-color: var(--pico-color-orange-200);
  color: var(--pico-color-dark);
}

.pico-background-orange-150 {
  background-color: var(--pico-color-orange-150);
  color: var(--pico-color-dark);
}

.pico-background-orange-100 {
  background-color: var(--pico-color-orange-100);
  color: var(--pico-color-dark);
}

.pico-background-orange-50 {
  background-color: var(--pico-color-orange-50);
  color: var(--pico-color-dark);
}

.pico-background-orange {
  background-color: var(--pico-color-orange);
  color: var(--pico-color-light);
}

.pico-background-sand-950 {
  background-color: var(--pico-color-sand-950);
  color: var(--pico-color-light);
}

.pico-background-sand-900 {
  background-color: var(--pico-color-sand-900);
  color: var(--pico-color-light);
}

.pico-background-sand-850 {
  background-color: var(--pico-color-sand-850);
  color: var(--pico-color-light);
}

.pico-background-sand-800 {
  background-color: var(--pico-color-sand-800);
  color: var(--pico-color-light);
}

.pico-background-sand-750 {
  background-color: var(--pico-color-sand-750);
  color: var(--pico-color-light);
}

.pico-background-sand-700 {
  background-color: var(--pico-color-sand-700);
  color: var(--pico-color-light);
}

.pico-background-sand-650 {
  background-color: var(--pico-color-sand-650);
  color: var(--pico-color-light);
}

.pico-background-sand-600 {
  background-color: var(--pico-color-sand-600);
  color: var(--pico-color-light);
}

.pico-background-sand-550 {
  background-color: var(--pico-color-sand-550);
  color: var(--pico-color-light);
}

.pico-background-sand-500 {
  background-color: var(--pico-color-sand-500);
  color: var(--pico-color-light);
}

.pico-background-sand-450 {
  background-color: var(--pico-color-sand-450);
  color: var(--pico-color-dark);
}

.pico-background-sand-400 {
  background-color: var(--pico-color-sand-400);
  color: var(--pico-color-dark);
}

.pico-background-sand-350 {
  background-color: var(--pico-color-sand-350);
  color: var(--pico-color-dark);
}

.pico-background-sand-300 {
  background-color: var(--pico-color-sand-300);
  color: var(--pico-color-dark);
}

.pico-background-sand-250 {
  background-color: var(--pico-color-sand-250);
  color: var(--pico-color-dark);
}

.pico-background-sand-200 {
  background-color: var(--pico-color-sand-200);
  color: var(--pico-color-dark);
}

.pico-background-sand-150 {
  background-color: var(--pico-color-sand-150);
  color: var(--pico-color-dark);
}

.pico-background-sand-100 {
  background-color: var(--pico-color-sand-100);
  color: var(--pico-color-dark);
}

.pico-background-sand-50 {
  background-color: var(--pico-color-sand-50);
  color: var(--pico-color-dark);
}

.pico-background-sand {
  background-color: var(--pico-color-sand);
  color: var(--pico-color-dark);
}

.pico-background-grey-950 {
  background-color: var(--pico-color-grey-950);
  color: var(--pico-color-light);
}

.pico-background-grey-900 {
  background-color: var(--pico-color-grey-900);
  color: var(--pico-color-light);
}

.pico-background-grey-850 {
  background-color: var(--pico-color-grey-850);
  color: var(--pico-color-light);
}

.pico-background-grey-800 {
  background-color: var(--pico-color-grey-800);
  color: var(--pico-color-light);
}

.pico-background-grey-750 {
  background-color: var(--pico-color-grey-750);
  color: var(--pico-color-light);
}

.pico-background-grey-700 {
  background-color: var(--pico-color-grey-700);
  color: var(--pico-color-light);
}

.pico-background-grey-650 {
  background-color: var(--pico-color-grey-650);
  color: var(--pico-color-light);
}

.pico-background-grey-600 {
  background-color: var(--pico-color-grey-600);
  color: var(--pico-color-light);
}

.pico-background-grey-550 {
  background-color: var(--pico-color-grey-550);
  color: var(--pico-color-light);
}

.pico-background-grey-500 {
  background-color: var(--pico-color-grey-500);
  color: var(--pico-color-light);
}

.pico-background-grey-450 {
  background-color: var(--pico-color-grey-450);
  color: var(--pico-color-dark);
}

.pico-background-grey-400 {
  background-color: var(--pico-color-grey-400);
  color: var(--pico-color-dark);
}

.pico-background-grey-350 {
  background-color: var(--pico-color-grey-350);
  color: var(--pico-color-dark);
}

.pico-background-grey-300 {
  background-color: var(--pico-color-grey-300);
  color: var(--pico-color-dark);
}

.pico-background-grey-250 {
  background-color: var(--pico-color-grey-250);
  color: var(--pico-color-dark);
}

.pico-background-grey-200 {
  background-color: var(--pico-color-grey-200);
  color: var(--pico-color-dark);
}

.pico-background-grey-150 {
  background-color: var(--pico-color-grey-150);
  color: var(--pico-color-dark);
}

.pico-background-grey-100 {
  background-color: var(--pico-color-grey-100);
  color: var(--pico-color-dark);
}

.pico-background-grey-50 {
  background-color: var(--pico-color-grey-50);
  color: var(--pico-color-dark);
}

.pico-background-grey {
  background-color: var(--pico-color-grey);
  color: var(--pico-color-dark);
}

.pico-background-zinc-950 {
  background-color: var(--pico-color-zinc-950);
  color: var(--pico-color-light);
}

.pico-background-zinc-900 {
  background-color: var(--pico-color-zinc-900);
  color: var(--pico-color-light);
}

.pico-background-zinc-850 {
  background-color: var(--pico-color-zinc-850);
  color: var(--pico-color-light);
}

.pico-background-zinc-800 {
  background-color: var(--pico-color-zinc-800);
  color: var(--pico-color-light);
}

.pico-background-zinc-750 {
  background-color: var(--pico-color-zinc-750);
  color: var(--pico-color-light);
}

.pico-background-zinc-700 {
  background-color: var(--pico-color-zinc-700);
  color: var(--pico-color-light);
}

.pico-background-zinc-650 {
  background-color: var(--pico-color-zinc-650);
  color: var(--pico-color-light);
}

.pico-background-zinc-600 {
  background-color: var(--pico-color-zinc-600);
  color: var(--pico-color-light);
}

.pico-background-zinc-550 {
  background-color: var(--pico-color-zinc-550);
  color: var(--pico-color-light);
}

.pico-background-zinc-500 {
  background-color: var(--pico-color-zinc-500);
  color: var(--pico-color-light);
}

.pico-background-zinc-450 {
  background-color: var(--pico-color-zinc-450);
  color: var(--pico-color-dark);
}

.pico-background-zinc-400 {
  background-color: var(--pico-color-zinc-400);
  color: var(--pico-color-dark);
}

.pico-background-zinc-350 {
  background-color: var(--pico-color-zinc-350);
  color: var(--pico-color-dark);
}

.pico-background-zinc-300 {
  background-color: var(--pico-color-zinc-300);
  color: var(--pico-color-dark);
}

.pico-background-zinc-250 {
  background-color: var(--pico-color-zinc-250);
  color: var(--pico-color-dark);
}

.pico-background-zinc-200 {
  background-color: var(--pico-color-zinc-200);
  color: var(--pico-color-dark);
}

.pico-background-zinc-150 {
  background-color: var(--pico-color-zinc-150);
  color: var(--pico-color-dark);
}

.pico-background-zinc-100 {
  background-color: var(--pico-color-zinc-100);
  color: var(--pico-color-dark);
}

.pico-background-zinc-50 {
  background-color: var(--pico-color-zinc-50);
  color: var(--pico-color-dark);
}

.pico-background-zinc {
  background-color: var(--pico-color-zinc);
  color: var(--pico-color-light);
}

.pico-background-slate-950 {
  background-color: var(--pico-color-slate-950);
  color: var(--pico-color-light);
}

.pico-background-slate-900 {
  background-color: var(--pico-color-slate-900);
  color: var(--pico-color-light);
}

.pico-background-slate-850 {
  background-color: var(--pico-color-slate-850);
  color: var(--pico-color-light);
}

.pico-background-slate-800 {
  background-color: var(--pico-color-slate-800);
  color: var(--pico-color-light);
}

.pico-background-slate-750 {
  background-color: var(--pico-color-slate-750);
  color: var(--pico-color-light);
}

.pico-background-slate-700 {
  background-color: var(--pico-color-slate-700);
  color: var(--pico-color-light);
}

.pico-background-slate-650 {
  background-color: var(--pico-color-slate-650);
  color: var(--pico-color-light);
}

.pico-background-slate-600 {
  background-color: var(--pico-color-slate-600);
  color: var(--pico-color-light);
}

.pico-background-slate-550 {
  background-color: var(--pico-color-slate-550);
  color: var(--pico-color-light);
}

.pico-background-slate-500 {
  background-color: var(--pico-color-slate-500);
  color: var(--pico-color-light);
}

.pico-background-slate-450 {
  background-color: var(--pico-color-slate-450);
  color: var(--pico-color-dark);
}

.pico-background-slate-400 {
  background-color: var(--pico-color-slate-400);
  color: var(--pico-color-dark);
}

.pico-background-slate-350 {
  background-color: var(--pico-color-slate-350);
  color: var(--pico-color-dark);
}

.pico-background-slate-300 {
  background-color: var(--pico-color-slate-300);
  color: var(--pico-color-dark);
}

.pico-background-slate-250 {
  background-color: var(--pico-color-slate-250);
  color: var(--pico-color-dark);
}

.pico-background-slate-200 {
  background-color: var(--pico-color-slate-200);
  color: var(--pico-color-dark);
}

.pico-background-slate-150 {
  background-color: var(--pico-color-slate-150);
  color: var(--pico-color-dark);
}

.pico-background-slate-100 {
  background-color: var(--pico-color-slate-100);
  color: var(--pico-color-dark);
}

.pico-background-slate-50 {
  background-color: var(--pico-color-slate-50);
  color: var(--pico-color-dark);
}

.pico-background-slate {
  background-color: var(--pico-color-slate);
  color: var(--pico-color-light);
}
